==> hasura_connect-2.0.0-dev.1.tar.gz: test/src/infra/repositories/request_repository_test.dart <==
import 'package:dartz/dartz.dart';
import 'package:hasura_connect/src/domain/entities/response.dart';
import 'package:hasura_connect/src/domain/errors/errors.dart';
import 'package:hasura_connect/src/domain/models/query.dart';
import 'package:hasura_connect/src/domain/models/request.dart';
import 'package:hasura_connect/src/domain/repositories/request_repository.dart';
import 'package:hasura_connect/src/infra/datasources/request_datasource.dart';
import 'package:hasura_connect/src/infra/repositories/request_repository.dart';
import 'package:mockito/mockito.dart';
import 'package:test/test.dart';

class RequestDatasourceMock extends Mock implements RequestDatasource {}

void main() {
  RequestDatasource datasource;
  RequestRepository repository;
  final tRequest =
      Request(url: '', query: Query(document: 'query', key: 'dadas'));
  setUpAll(() {
    datasource = RequestDatasourceMock();
    repository = RequestRepositoryImpl(datasource: datasource);
  });

  test('should return Response', () async {
    when(datasource.post(request: anyNamed('request')))
        .thenAnswer((_) async => const Response());
    final result = await repository.sendRequest(request: tRequest);
    expect(result | null, equals(const Response()));
  });

  test('should return DatasourceError when datasource failed', () async {
    when(datasource.post(request: anyNamed('request'))).thenThrow(Exception());
    final result = await repository.sendRequest(request: tRequest);
    expect(
        result.fold(id, id), equals(const DatasourceError('Datasource Error')));
  });
}

==> hasura_connect-3.0.4.tar.gz: test/src/infra/repositories/request_repository_test.dart <==
import 'package:hasura_connect/src/domain/entities/response.dart';
import 'package:hasura_connect/src/domain/errors/errors.dart';
import 'package:hasura_connect/src/domain/models/query.dart';
import 'package:hasura_connect/src/domain/models/request.dart';
import 'package:hasura_connect/src/domain/repositories/request_repository.dart';
import 'package:hasura_connect/src/infra/datasources/request_datasource.dart';
import 'package:hasura_connect/src/infra/repositories/request_repository.dart';
import 'package:mocktail/mocktail.dart';
import 'package:test/test.dart';

class RequestDatasourceMock extends Mock implements RequestDatasource {}

class ResponseMock extends Mock implements Response {}

void main() {
  late RequestDatasource datasource;
  late RequestRepository repository;
  late Response response;

  final tRequest = Request(url: '', query: Query(document: 'query', key: 'dadas'));
  setUpAll(() {
    response = ResponseMock();
    datasource = RequestDatasourceMock();
    repository = RequestRepositoryImpl(datasource: datasource);
  });

  test('should return Response', () async {
    when(datasource).calls(#post).thenAnswer((_) async => response);
    final result = await repository.sendRequest(request: tRequest);
    expect(result.right, equals(response));
  });

  test('should return DatasourceError when datasource failed', () async {
    when(datasource).calls(#post).thenThrow(Exception());
    final result = await repository.sendRequest(request: tRequest);
    expect(result.left, isA<DatasourceError>());
  });

  test('should return error from datasource', () async {
    when(datasource).calls(#post).thenThrow(InvalidRequestError('Error'));
    final result = await repository.sendRequest(request: tRequest);
    expect(result.left, isA<InvalidRequestError>());
  });
}
